@@ -6,8 +6,8 @@
 #' When a variable is lagged twice, special care is needed to insert NA's for
 #' the first two time points (e.g. weeks) for each entity (country).
 #'
-#' @param ID {location of the column having time identities (e.g. the week number)}
-#' @param xj {data on variable to be lagged linked to ID}
+#' @param ID {Location of the column having time identities (e.g. the week number)}
+#' @param xj {Data on variable to be lagged linked to ID}
 #' @return Vector containing  2 lagged values of xj.
 #' @seealso A more general function \code{\link{PanelLag}} has examples.
 #' @note This function is provided for convenient user modifications.
@@ -16,12 +16,16 @@
 #'
 #' @export
 
-Panel2Lag <-
-function(ID,xj){
-nr=length(as.vector(ID))
-outj=rep(NA,nr)
-for (i in 1:nr){
-if (ID[i]==1)  outj[i]=NA
-if (ID[i]==2)  outj[i]=NA
-if (ID[i]>2)  outj[i]=xj[i-2]}
-return(outj)}
+Panel2Lag <- function(ID, xj) {
+    nr = length(as.vector(ID))
+    outj = rep(NA, nr)
+    for (i in 1:nr) {
+        if (ID[i] == 1) 
+            outj[i] = NA
+        if (ID[i] == 2) 
+            outj[i] = NA
+        if (ID[i] > 2) 
+            outj[i] = xj[i - 2]
+    }
+    return(outj)
+} 
